==> dts-client-library-2.0.0-20130930.003954-79-sources.jar: org/gcube/datatransformation/client/library/beans/Types.java <==
package org.gcube.datatransformation.client.library.beans;

import java.util.List;

import javax.xml.bind.annotation.XmlElement;

public class Types {
	// REQUEST AND RESPONSE ELEMENTS

	// REQUESTS

	// For method transformData
	public static class TransformData {
		@XmlElement(name = "input")
		public Input input;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;

		@XmlElement(name = "output")
		public Output output;

		@XmlElement(name = "createReport", required = true)
		public Boolean createReport;
	}

	// For method transformDataWithTransformationProgram
	public static class TransformDataWithTransformationProgram {
		@XmlElement(name = "input")
		public Input input;
		
		@XmlElement(name = "TPID")
		public String tpID;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;
		
		@XmlElement(name = "tProgramUnboundParameters")
		public List<Parameter> tProgramUnboundParameters;
		
		@XmlElement(name = "output")
		public Output output;
		
		@XmlElement(name = "createReport", required = true)
		public Boolean createReport;
	}
	
	// For method transformDataWithTransformationUnit
	public static class TransformDataWithTransformationUnit {
		@XmlElement(name = "inputs", required = true)
		public List<Input> inputs;
		
		@XmlElement(name = "TPID")
		public String tpID;

		@XmlElement(name = "transformationUnitID")
		public String transformationUnitID;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;
		
		@XmlElement(name = "tProgramUnboundParameters")
		public List<Parameter> tProgramUnboundParameters;
		
		@XmlElement(name = "output")
		public Output output;
		
		@XmlElement(name = "filterSources", required = true)
		public Boolean filterSources;
		
		@XmlElement(name = "createReport", required = true)
		public Boolean createReport;
	}
	
	// For method findApplicableTransformationUnits
	public static class FindApplicableTransformationUnits {
		@XmlElement(name = "sourceContentType", required = true)
		public ContentType sourceContentType;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;

		@XmlElement(name = "createAndPublishCompositeTP", required = true)
		public Boolean createAndPublishCompositeTP;
	}

	// For method findAvailableTargetContentTypes
	public static class FindAvailableTargetContentTypes {
		@XmlElement(name = "sourceContentType", required = true)
		public ContentType sourceContentType;
	}

	// For method QueryTransformationPrograms
	public static class QueryTransformationPrograms {
		@XmlElement(name = "queryTransformationPrograms")
		public String queryTransformationPrograms;
	}

	// For method EvaluateContentTypeByDataElementID
	public static class EvaluateContentTypeByDataElementID {
		@XmlElement(name = "evaluatorType", required = true)
		public String evaluatorType;

		@XmlElement(name = "dataElementIDs", required = true)
		public List<String> dataElementIDs;
}

	// RESPONSES

	// For method transformData
	public static class TransformDataResponse {
		@XmlElement(name = "output", required = true)
		public String output;
		
		@XmlElement(name = "reportEPR", required = true)
		public String reportEPR;
	}
	
	// For method transformDataWithTransformationProgram
	public static class TransformDataWithTransformationProgramResponse {
		@XmlElement(name = "output", required = true)
		public String output;
		
		@XmlElement(name = "reportEPR", required = true)
		public String reportEPR;
	}
	
	// For method transformDataWithTransformationUnit
	public static class TransformDataWithTransformationUnitResponse {
		@XmlElement(name = "output", required = true)
		public String output;
		
		@XmlElement(name = "reportEPR", required = true)
		public String reportEPR;
	}
	
	// For method findApplicableTransformationUnits
	public static class FindApplicableTransformationUnitsResponse {
		@XmlElement(name = "TPAndTransformationUnitIDs")
		public List<TPAndTransformationUnit> TPAndTransformationUnitIDs;
	}
	
	// For method findAvailableTargetContentTypes
	public static class FindAvailableTargetContentTypesResponse {
		@XmlElement(name = "targetContentTypes", required = true)
		public List<ArrayOfContentTypes> targetContentTypes;
	}
	
	// For method queryTransformationPrograms
	public static class QueryTransformationProgramsResponse {
		@XmlElement(name = "queryTransformationProgramsResponse")
		public String queryTransformationProgramsResponse;
	}
	
	// For method evaluateContentTypeByDataElementID
	public static class EvaluateContentTypeByDataElementIDResponse {
		@XmlElement(name = "evaluateContentTypeByDataElementIDResponse", required = true)
		public ArrayOfDataElementIDandContentType evaluateContentTypeByDataElementIDResponse;
	}
	
	// DTS Types

	public static class Input {
		@XmlElement(name = "inputType")
		public String inputType;

		@XmlElement(name = "inputValue")
		public String inputValue;

		@XmlElement(name = "inputparameters")
		public List<Parameter> inputparameters;
	}

	public static class Output {
		@XmlElement(name = "outputType")
		public String outputType;

		@XmlElement(name = "outputValue")
		public String outputValue;

		@XmlElement(name = "outputparameters")
		public List<Parameter> outputparameters;
	}

	public static class ContentType {
		@XmlElement(name = "mimeType", required = true)
		public String mimeType;

		@XmlElement(name = "parameters")
		public List<Parameter> parameters;
	}

	public static class ArrayOfContentTypes {
		@XmlElement(name = "contentTypesArray")
		public List<ContentType> contentTypesArray;
	}
	
	public static class Parameter {
		@XmlElement(name = "name", required = true)
		public String name;

		@XmlElement(name = "value", required = true)
		public String value;
	}
	
	public static class TPAndTransformationUnit {
		@XmlElement(name = "transformationProgramID")
		public String transformationProgramID;

		@XmlElement(name = "transformationUnitID")
		public String transformationUnitID;
	}
	
	public static class DataElementIDandContentType {
		@XmlElement(name = "dataElementID", required = true)
		public String dataElementID;

		@XmlElement(name = "contentType", required = true)
		public ContentType contentType;
	}
	
	public static class ArrayOfDataElementIDandContentType {
		@XmlElement(name = "dataElementIDAndContentType")
		public List<DataElementIDandContentType> dataElementIDAndContentType;
	}
}

==> dts-client-library-3.0.0-20140222.230724-40-sources.jar: org/gcube/datatransformation/client/library/beans/Types.java <==
package org.gcube.datatransformation.client.library.beans;

import java.util.List;

import javax.xml.bind.annotation.XmlElement;

public class Types {
	// REQUEST AND RESPONSE ELEMENTS

	// REQUESTS

	// For method transformData
	public static class TransformData {
		@XmlElement(name = "input")
		public Input input;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;

		@XmlElement(name = "output")
		public Output output;

		@XmlElement(name = "createReport", required = true)
		public Boolean createReport;
	}

	// For method transformDataWithTransformationProgram
	public static class TransformDataWithTransformationProgram {
		@XmlElement(name = "input")
		public Input input;
		
		@XmlElement(name = "TPID")
		public String tpID;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;
		
		@XmlElement(name = "tProgramUnboundParameters")
		public List<Parameter> tProgramUnboundParameters;
		
		@XmlElement(name = "output")
		public Output output;
		
		@XmlElement(name = "createReport", required = true)
		public Boolean createReport;
	}
	
	// For method transformDataWithTransformationUnit
	public static class TransformDataWithTransformationUnit {
		@XmlElement(name = "inputs", required = true)
		public List<Input> inputs;
		
		@XmlElement(name = "TPID")
		public String tpID;

		@XmlElement(name = "transformationUnitID")
		public String transformationUnitID;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;
		
		@XmlElement(name = "tProgramUnboundParameters")
		public List<Parameter> tProgramUnboundParameters;
		
		@XmlElement(name = "output")
		public Output output;
		
		@XmlElement(name = "filterSources", required = true)
		public Boolean filterSources;
		
		@XmlElement(name = "createReport", required = true)
		public Boolean createReport;
	}
	
	// For method findApplicableTransformationUnits
	public static class FindApplicableTransformationUnits {
		@XmlElement(name = "sourceContentType", required = true)
		public ContentType sourceContentType;

		@XmlElement(name = "targetContentType", required = true)
		public ContentType targetContentType;

		@XmlElement(name = "createAndPublishCompositeTP", required = true)
		public Boolean createAndPublishCompositeTP;
	}

	// For method findAvailableTargetContentTypes
	public static class FindAvailableTargetContentTypes {
		@XmlElement(name = "sourceContentType", required = true)
		public ContentType sourceContentType;
	}

	// For method QueryTransformationPrograms
	public static class QueryTransformationPrograms {
		@XmlElement(name = "queryTransformationPrograms")
		public String queryTransformationPrograms;
	}

	// For method EvaluateContentTypeByDataElementID
	public static class EvaluateContentTypeByDataElementID {
		@XmlElement(name = "evaluatorType", required = true)
		public String evaluatorType;

		@XmlElement(name = "dataElementIDs", required = true)
		public List<String> dataElementIDs;
}

	// RESPONSES

	// For method transformData
	public static class TransformDataResponse {
		@XmlElement(name = "output", required = true)
		public String output;
		
		@XmlElement(name = "reportEPR", required = true)
		public String reportEPR;
	}
	
	// For method transformDataWithTransformationProgram
	public static class TransformDataWithTransformationProgramResponse {
		@XmlElement(name = "output", required = true)
		public String output;
		
		@XmlElement(name = "reportEPR", required = true)
		public String reportEPR;
	}
	
	// For method transformDataWithTransformationUnit
	public static class TransformDataWithTransformationUnitResponse {
		@XmlElement(name = "output", required = true)
		public String output;
		
		@XmlElement(name = "reportEPR", required = true)
		public String reportEPR;
	}
	
	// For method findApplicableTransformationUnits
	public static class FindApplicableTransformationUnitsResponse {
		@XmlElement(name = "TPAndTransformationUnitIDs")
		public List<TPAndTransformationUnit> TPAndTransformationUnitIDs;
	}
	
	// For method findAvailableTargetContentTypes
	public static class FindAvailableTargetContentTypesResponse {
		@XmlElement(name = "targetContentTypes", required = true)
		public List<ArrayOfContentTypes> targetContentTypes;
	}
	
	// For method queryTransformationPrograms
	public static class QueryTransformationProgramsResponse {
		@XmlElement(name = "queryTransformationProgramsResponse")
		public String queryTransformationProgramsResponse;
	}
	
	// For method evaluateContentTypeByDataElementID
	public static class EvaluateContentTypeByDataElementIDResponse {
		@XmlElement(name = "evaluateContentTypeByDataElementIDResponse", required = true)
		public ArrayOfDataElementIDandContentType evaluateContentTypeByDataElementIDResponse;
	}
	
	// DTS Types

	public static class Input {
		@XmlElement(name = "inputType")
		public String inputType;

		@XmlElement(name = "inputValue")
		public String inputValue;

		@XmlElement(name = "inputparameters")
		public List<Parameter> inputparameters;
	}

	public static class Output {
		@XmlElement(name = "outputType")
		public String outputType;

		@XmlElement(name = "outputValue")
		public String outputValue;

		@XmlElement(name = "outputparameters")
		public List<Parameter> outputparameters;
	}

	public static class ContentType {
		@XmlElement(name = "mimeType", required = true)
		public String mimeType;

		@XmlElement(name = "parameters")
		public List<Parameter> parameters;
	}

	public static class ArrayOfContentTypes {
		@XmlElement(name = "contentTypesArray")
		public List<ContentType> contentTypesArray;
	}
	
	public static class Parameter {
		@XmlElement(name = "name", required = true)
		public String name;

		@XmlElement(name = "value", required = true)
		public String value;
		
		public Parameter() {
		}

		public Parameter(String name, String value) {
			this.name = name;
			this.value = value;
		}
	}
	
	public static class TPAndTransformationUnit {
		@XmlElement(name = "transformationProgramID")
		public String transformationProgramID;

		@XmlElement(name = "transformationUnitID")
		public String transformationUnitID;
	}
	
	public static class DataElementIDandContentType {
		@XmlElement(name = "dataElementID", required = true)
		public String dataElementID;

		@XmlElement(name = "contentType", required = true)
		public ContentType contentType;
	}
	
	public static class ArrayOfDataElementIDandContentType {
		@XmlElement(name = "dataElementIDAndContentType")
		public List<DataElementIDandContentType> dataElementIDAndContentType;
	}
}
